import { ChartAnnotation, ChartDimension, ChartMeasure, ChartSettings, EntityType, PropertyHierarchy, QueryReturn, TreeNodeInterface } from '@metad/ocap-core';
import { EChartsContext, EChartsOptions } from './types';
export declare function tree(data: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options?: EChartsOptions): {
    echartsOptions: {
        tooltip: any;
        series: any[];
    };
    onClick: (event: any) => any;
    data: QueryReturn<unknown>;
    chartAnnotation: ChartAnnotation;
    entityType: EntityType;
    settings: ChartSettings;
    options: EChartsOptions;
} | {
    echartsOptions: {
        series: {
            type: string;
            id: string;
            universalTransition: boolean;
            data: unknown[];
            links: any[];
        }[];
        tooltip?: undefined;
    };
    onClick: (event: any) => any;
    data: QueryReturn<unknown>;
    chartAnnotation: ChartAnnotation;
    entityType: EntityType;
    settings: ChartSettings;
    options: EChartsOptions;
};
/**
 * Calc ECharts options for TreeMap chart
 *
 * @param result
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export declare function treemap(result: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): EChartsContext;
export declare function treemapMeasure(measure: ChartMeasure, result: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): any;
/**
 * Calc ECharts options for Sunburst chart
 *
 * @param result
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export declare function sunburst(result: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): EChartsContext;
export declare function sunburstMeasure(measure: ChartMeasure, result: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): any;
export declare function treeDataForMeasure(measure: ChartMeasure, result: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType): {
    data: TreeNodeInterface<unknown>[];
    levels: unknown[];
    recursiveHierarchy: boolean;
};
/**
 * Calc ECharts options for Sankey chart
 *
 * @param result
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export declare function sankey(data: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): EChartsContext;
export declare function sankeyMeasure(measure: ChartMeasure, data: QueryReturn<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, settings: ChartSettings, options: EChartsOptions): any;
/**
 * Calc leveled hierarchy data for measure
 *
 * @param data
 * @param chartAnnotation
 * @param entityType
 * @param aggregator
 * @returns
 */
export declare function leveledHierarchy(data: Array<unknown>, measure: ChartMeasure, levels: ChartDimension[], entityType: EntityType, aggregator: (data: any, key: any) => number): TreeNodeInterface<unknown>[];
/**
 *
 * @param data
 * @param chartAnnotation
 * @param aggregator
 */
export declare function leveledGraph(data: Array<unknown>, chartAnnotation: ChartAnnotation, entityType: EntityType, aggregator: (data: any, key: any) => number): {
    nodes: unknown[];
    links: any[];
};
export declare function convertTree2NodeLinks(data: Array<unknown>, child: PropertyHierarchy, parent: string, level: string, dimension: ChartDimension, measure: string, options: EChartsOptions): {
    nodes: any[];
    links: any[];
};
export declare function onClick(event: any, chartAnnotation: ChartAnnotation, isHierarchy: boolean): any;
