import { ChartAnnotation, ChartDimension, ChartMeasure, ChartOptions, ChartSettings, EntityType } from '@metad/ocap-core';
import { IDataset } from './types';
/**
 * 使用 ChartAnnotation 中的 series dimension 将一维数组数据转换成二维数组数据, 然后放在 ECharts 的 DateSet 中, 然后给 stack series 等使用.
 * Capacities:
 * * Calculate two-dimensional array for DateSet
 * * Calculate ECharts component config for series of category2 dimension members
 * * Tooltip ?
 *
 * @param results
 * @param measure
 * @param chartAnnotation
 * @param entityType
 * @param settings
 * @param options
 * @returns
 */
export declare function stackedForMeasure(data: Array<unknown>, measure: ChartMeasure, chartAnnotation: ChartAnnotation, entityType: EntityType, settings?: ChartSettings, options?: ChartOptions): IDataset;
/**
 * 将一维数组 items 按照 category 和 category2 维度, 与 measure 为单元格转换成二位数组
 *
 * Capacities:
 * * Sort category dimension by member key and order in dimension
 * * Sort category2 dimension by cell measure value of category last member column and order in measure
 *
 * @param items
 * @param entityType
 * @param category
 * @param category2
 * @param measure
 * @returns
 */
export declare function getMatrixForMeasure(items: Array<unknown>, entityType: EntityType, category: ChartDimension, category2: ChartDimension, measure: ChartMeasure): {
    categoryValues: {
        value: any;
        label: any;
    }[];
    category2Values: {
        value: any;
        label: any;
    }[];
    source: any[][];
    dataMin: any;
    dataMax: any;
};
export declare function getDatasetIdForMeasure(name: string): string;
